'use client';

import {
  Box,
  Container,
  Heading,
  SimpleGrid,
  Text,
  Link as ChakraLink,
  Button,
  Stack,
  List,
  ListItem,
  ListIcon,
} from '@chakra-ui/react';
import { CheckCircleIcon } from '@chakra-ui/icons';
import { resources } from '../constants/resources';

export default function ResourcesPageClient() {
  return (
    <Box as="main" py={10}>
      <Container maxW="7xl">
        <Heading as="h1" mb={6} fontSize={{ base: '3xl', md: '5xl' }}>
          Helpful Resources for Mental Wellness
        </Heading>

        <SimpleGrid columns={{ base: 1, md: 2 }} spacing={10} alignItems="start">
          <Box>
            <Text fontSize="lg" mb={8} color="gray.600" maxW="lg">
              Navigating mental health challenges can be difficult. Below are trusted organizations and
              platforms offering support, counseling, and guidance for those dealing with depression,
              anxiety, and emotional distress.
            </Text>

            <Box as="section" aria-labelledby="tips-heading" mb={10}>
              <Heading id="tips-heading" as="h2" mb={4} fontSize={{ base: '2xl', md: '3xl' }}>
                Tips for Maintaining Mental Wellness
              </Heading>
              <List spacing={3} maxW="lg">
                <ListItem>
                  <ListIcon as={CheckCircleIcon} color="teal.500" />
                  Stay connected with supportive friends and family.
                </ListItem>
                <ListItem>
                  <ListIcon as={CheckCircleIcon} color="teal.500" />
                  Practice mindfulness and meditation regularly.
                </ListItem>
                <ListItem>
                  <ListIcon as={CheckCircleIcon} color="teal.500" />
                  Seek professional help when feeling overwhelmed.
                </ListItem>
                <ListItem>
                  <ListIcon as={CheckCircleIcon} color="teal.500" />
                  Engage in physical activities and maintain a balanced diet.
                </ListItem>
                <ListItem>
                  <ListIcon as={CheckCircleIcon} color="teal.500" />
                  Limit exposure to negative news and social media.
                </ListItem>
              </List>
            </Box>

            <Box mt={4} p={6} bg="teal.50" borderRadius="xl" maxW="lg" boxShadow="md">
              <Heading as="h3" size="md" mb={4} color="teal.700">
                Join Our Supportive Community
              </Heading>
              <Text mb={4} color="gray.700">
                Connect with others, share your story, and find encouragement in our online forum.
              </Text>
              <Button
                colorScheme="teal"
                as="a"
                href="https://community.yoursite.com"
                target="_blank"
                rel="noopener noreferrer"
              >
                Visit the Forum
              </Button>
            </Box>
          </Box>

          <SimpleGrid columns={{ base: 1, md: 1 }} spacing={6}>
            {resources.map(({ id, title, description, url }) => (
              <Box
                key={id}
                as="article"
                shadow="md"
                borderRadius="xl"
                overflow="hidden"
                borderWidth="1px"
                borderColor="gray.200"
                _hover={{ borderColor: 'teal.400', shadow: 'lg' }}
                transition="all 0.3s ease"
                p={6}
              >
                <Stack spacing={4}>
                  <Heading as="h2" fontSize="xl" color="teal.600">
                    {title}
                  </Heading>
                  <Text color="gray.700">{description}</Text>
                  <ChakraLink href={url} isExternal style={{ textDecoration: 'none' }}>
                    <Button colorScheme="teal" size="sm" alignSelf="start">
                      Visit
                    </Button>
                  </ChakraLink>
                </Stack>
              </Box>
            ))}
          </SimpleGrid>
        </SimpleGrid>
      </Container>
    </Box>
  );
}
